Tools to download global and European spatial data from the 'Eurostat' 'GISCO' (Geographic Information System of the Commission) data distribution https://ec.europa.eu/eurostat/web/gisco. The package provides helpers for country boundaries, Nomenclature of Territorial Units for Statistics ('NUTS') regions, administrative units, statistical units, transport networks, basic service locations and other 'GISCO' datasets. This package is neither affiliated with nor endorsed by 'Eurostat'.
Author
Maintainer: Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Authors:
Diego Hernangómez diego.hernangomezherrero@gmail.com (ORCID) [copyright holder]
Other contributors:
Eurostat (ROR) [copyright holder]
EuroGeographics [copyright holder]