Skip to contents

A tibble containing conversions between country code schemes (Eurostat, ISO 3166-1 alpha-2 and ISO 3166-1 alpha-3) and geographic regions from the World Bank and the UN (M49 Standard). This database was extracted from the countrycode package.

Format

A data frame with 249 rows and 13 variables:

ISO3_CODE

ISO 3166-1 alpha-3 code of each country.

CNTR_CODE

Eurostat country code.

iso2c

ISO 3166-1 alpha-2 code of each country.

iso.name.en

ISO English short name.

cldr.short.en

English short name as provided by the Unicode Common Locale Data Repository.

continent

Continent from the World Bank.

un.region.code

UN M49 numeric region code.

un.region.name

UN M49 region name.

un.regionintermediate.code

UN M49 numeric intermediate region code.

un.regionintermediate.name

UN M49 intermediate region name.

un.regionsub.code

UN M49 numeric subregion code.

un.regionsub.name

UN M49 subregion name.

eu

Logical value indicating whether the country belongs to the European Union.

countrycode::codelist v1.6.1.

World regions

Regions follow the UN geographic regions (see https://unstats.un.org/unsd/methodology/m49/). Under this scheme Cyprus is assigned to Asia.

Examples

data("gisco_countrycode")
dplyr::glimpse(gisco_countrycode)
#> Rows: 249
#> Columns: 13
#> $ ISO3_CODE                  <chr> "ABW", "AFG", "AGO", "AIA", "ALA", "ALB", "…
#> $ CNTR_CODE                  <chr> "AW", "AF", "AO", "AI", NA, "AL", "AD", "AE…
#> $ iso2c                      <chr> "AW", "AF", "AO", "AI", "AX", "AL", "AD", "…
#> $ iso.name.en                <chr> "Aruba", "Afghanistan", "Angola", "Anguilla…
#> $ cldr.short.en              <chr> "Aruba", "Afghanistan", "Angola", "Anguilla…
#> $ continent                  <chr> "Americas", "Asia", "Africa", "Americas", "…
#> $ un.region.code             <dbl> 19, 142, 2, 19, 150, 150, 150, 142, 19, 142…
#> $ un.region.name             <chr> "Americas", "Asia", "Africa", "Americas", "…
#> $ un.regionintermediate.code <dbl> 29, NA, 17, 29, NA, NA, NA, NA, 5, NA, NA, …
#> $ un.regionintermediate.name <chr> "Caribbean", NA, "Middle Africa", "Caribbea…
#> $ un.regionsub.code          <dbl> 419, 34, 202, 419, 154, 39, 39, 145, 419, 1…
#> $ un.regionsub.name          <chr> "Latin America and the Caribbean", "Souther…
#> $ eu                         <lgl> FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, F…