gisco_db: Cached GISCO database

gisco_dbR Documentation

Cached GISCO database

Description

Database with the list of files in the GISCO geodata distribution as of 2026-01-12.

Format

A tibble with 9,714 rows.

Details

This database is used to redirect the corresponding functions to the correct API endpoints.

This version of the database is used if there is a problem during update. Please use gisco_get_cached_db() with update_cache = TRUE to update the corresponding API endpoints.

GISCO geodata distribution datasets.json.

See Also

Other datasets: gisco_coastal_lines, gisco_countries_2024, gisco_countrycode, gisco_nuts_2024

Database utilities: gisco_get_cached_db(), gisco_get_metadata()

Examples

data("gisco_db")
gisco_db |>
  dplyr::glimpse()

giscoR documentation built on June 17, 2026, 9:10 a.m.