View source: R/gisco-get-airports.R
| gisco_get_airports | R Documentation |
This dataset includes the location of over 11,800 pan-European airports and heliports. The airports are identified using the International Civil Aviation Organization (ICAO) airport codes.
gisco_get_airports(
year = c(2013, 2006),
country = NULL,
cache_dir = NULL,
update_cache = FALSE,
verbose = FALSE
)
year |
A character string or numeric value with the release year of the
file.
One of |
country |
A character vector of country codes. It can be either a
vector of country names, a vector of ISO 3166-1 alpha-3 country codes or a
vector of Eurostat country codes. See also |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
verbose |
A logical value. If |
Files are distributed in EPSG:4326.
A sf object.
https://ec.europa.eu/eurostat/web/gisco/geodata/transport-networks.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata.
Transport network datasets:
gisco_get_ports()
airp <- gisco_get_airports(year = 2013)
coast <- giscoR::gisco_coastal_lines
if (!is.null(airp)) {
library(ggplot2)
ggplot(coast) +
geom_sf(fill = "grey10", color = "grey20") +
geom_sf(
data = airp, color = "#00F0FF",
size = 0.2, alpha = 0.25
) +
theme_void() +
theme(
plot.background = element_rect(fill = "black"),
text = element_text(color = "white"),
panel.grid = element_blank(),
plot.title = element_text(face = "bold", hjust = 0.5),
plot.subtitle = element_text(face = "italic", hjust = 0.5)
) +
labs(
title = "Airports in Europe", subtitle = "Year 2013",
caption = "Source: Eurostat, Airports 2013 dataset."
) +
# Center on Europe with EPSG 3035.
coord_sf(
crs = 3035,
xlim = c(2377294, 7453440),
ylim = c(1313597, 5628510)
)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.