gisco_get_cached_db: Retrieve and update the GISCO database used by 'giscoR'

View source: R/gisco-get-cached-db.R

gisco_get_cached_dbR Documentation

Retrieve and update the GISCO database used by giscoR

Description

Returns or optionally updates the cached database with endpoints from the GISCO geodata distribution.

Usage

gisco_get_cached_db(update_cache = FALSE)

Arguments

update_cache

A logical value. If TRUE, rebuild the cached database with the most recent information from the GISCO geodata distribution.

Details

The cached database is stored in the giscoR cache path. See gisco_set_cache_dir() for details. The cached database is used in subsequent R sessions.

On new GISCO data releases, you can access the updated data by refreshing the cached database without waiting for a new version of giscoR.

A static database gisco_db is shipped with the package. This database is used if there is any problem during the update.

Value

A tibble.

https://gisco-services.ec.europa.eu/distribution/v2/.

See Also

Database utilities: gisco_db, gisco_get_metadata()

Examples



gisco_get_cached_db() |>
  dplyr::glimpse()


giscoR documentation built on June 17, 2026, 9:10 a.m.