View source: R/gisco-get-communes.R
| gisco_get_communes | R Documentation |
This dataset shows pan-European administrative boundaries down to commune
level. Communes are equivalent to Local Administrative Units. See
gisco_get_lau().
gisco_get_communes(
year = 2016,
epsg = 4326,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
spatialtype = "RG",
country = NULL,
ext = "shp"
)
year |
A character string or numeric value with the release year of the file. One of \Sexpr[stage=render,results=rd]{giscoR:::db_values("communes", "year",TRUE)}. |
epsg |
A character string or numeric value with the coordinate reference system as a 4-digit EPSG code. One of:
|
cache |
|
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
verbose |
A logical value. If |
spatialtype |
A character string with the type of geometry to return. Options available are:
|
country |
A character vector of country codes. It can be either a
vector of country names, a vector of ISO 3166-1 alpha-3 country codes or a
vector of Eurostat country codes. See also |
ext |
A character value with the extension of the file (default
|
The Nomenclature of Territorial Units for Statistics (NUTS) and the LAU nomenclature are hierarchical classifications of statistical regions that together subdivide the EU economic territory into regions of five different levels, moving from larger to smaller territorial units: NUTS 1, 2 and 3 and LAU.
The dataset is based on EuroBoundaryMap from EuroGeographics. Geographical extent covers the European Union 28, EFTA countries and candidate countries. The scale of the dataset is 1:100 000.
The LAU classification is not covered by any legislative act.
A sf object.
Check the download and usage provisions in gisco_attributions().
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
gisco_get_lau().
See gisco_bulk_download() to perform a bulk download of datasets.
Administrative unit datasets:
gisco_get_countries(),
gisco_get_postal_codes()
ire_comm <- gisco_get_communes(spatialtype = "LB", country = "Ireland")
if (!is.null(ire_comm)) {
library(ggplot2)
ggplot(ire_comm) +
geom_sf(shape = 21, col = "#009A44", size = 0.5) +
labs(
title = "Communes in Ireland",
subtitle = "Year 2016",
caption = gisco_attributions()
) +
theme_void() +
theme(text = element_text(
colour = "#009A44",
family = "serif", face = "bold"
))
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.