View source: R/gisco-get-lau.R
| gisco_get_lau | R Documentation |
This dataset shows pan-European administrative boundaries down to commune
level. Local Administrative Units are equivalent to communes. See
gisco_get_communes().
gisco_get_lau(
year = 2024,
epsg = 4326,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
country = NULL,
gisco_id = NULL,
ext = "gpkg"
)
year |
A character string or numeric value with the release year of the file. One of \Sexpr[stage=render,results=rd]{giscoR:::db_values("lau", "year",TRUE)}. |
epsg |
A character string or numeric value with the coordinate reference system as a 4-digit EPSG code. One of:
|
cache |
|
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
verbose |
A logical value. If |
country |
A character vector of country codes. It can be either a
vector of country names, a vector of ISO 3166-1 alpha-3 country codes or a
vector of Eurostat country codes. See also |
gisco_id |
An optional character vector of |
ext |
A character value with the extension of the file (default
|
The Nomenclature of Territorial Units for Statistics (NUTS) and the LAU nomenclature are hierarchical classifications of statistical regions that together subdivide the EU economic territory into regions of five different levels, moving from larger to smaller territorial units: NUTS 1, 2 and 3 and LAU.
The LAU classification is not covered by any legislative act. Geographical extent covers the European Union, EFTA countries and candidate countries. The scale of the dataset is 1:100 000.
The data contain the National Statistical Agency LAU code, which can be
joined to LAU lists. They also contain a GISCO_ID field, which is a
unique identifier consisting of the country code and LAU code.
Total resident population figures (31 December) have also been added in some versions based on the associated LAU lists.
A sf object.
Check the download and usage provisions in gisco_attributions().
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/statistical-units.
gisco_get_communes().
See gisco_bulk_download() to perform a bulk download of datasets.
See gisco_id_api_lau() to download via GISCO ID service API.
Statistical unit datasets:
gisco_get_census(),
gisco_get_coastal_lines(),
gisco_get_nuts(),
gisco_get_urban_audit()
## Not run:
lu_lau <- gisco_get_lau(year = 2024, country = "Luxembourg")
if (!is.null(lu_lau)) {
library(ggplot2)
ggplot(lu_lau) +
geom_sf(aes(fill = POP_DENS_2024)) +
labs(
title = "Population density in Luxembourg",
subtitle = "Year 2024",
caption = gisco_attributions()
) +
scale_fill_viridis_b(
option = "cividis",
label = \(x) prettyNum(x, big.mark = ",")
) +
theme_void() +
labs(fill = "pop/km2")
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.