gisco_get_metadata: Get metadata

View source: R/gisco-get-metadata.R

gisco_get_metadataR Documentation

Get metadata

Description

Get a table with names and IDs of administrative and statistical units.

Usage

gisco_get_metadata(
  id = c("nuts", "countries", "urban_audit"),
  year = 2024,
  verbose = FALSE
)

Arguments

id

A character string with the unit type to download. Accepted values are "nuts", "countries" or "urban_audit".

year

A character string or numeric value with the release year of the metadata.

verbose

A logical value. If TRUE displays informational messages.

Value

A tibble.

https://gisco-services.ec.europa.eu/distribution/v2/.

See Also

gisco_get_nuts(), gisco_get_countries(), gisco_get_urban_audit().

Database utilities: gisco_db, gisco_get_cached_db()

Examples


cities <- gisco_get_metadata(id = "urban_audit", year = 2020)

cities


giscoR documentation built on June 17, 2026, 9:10 a.m.