View source: R/gisco-get-urban-audit.R
| gisco_get_urban_audit | R Documentation |
This dataset contains the boundaries of cities ("CITIES"), greater cities
("GREATER_CITIES") and functional urban areas ("FUA") defined according
to the EC-OECD city definition. It is used for the Eurostat Urban Audit data
collection.
Downloads data from the aggregated GISCO Urban Audit file. To download
single-unit Urban Audit files, use gisco_get_unit_urban_audit().
gisco_get_urban_audit(
year = 2024,
epsg = 4326,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
spatialtype = c("RG", "LB"),
country = NULL,
level = c("all", "CITIES", "FUA", "GREATER_CITIES", "CITY", "KERN", "LUZ"),
ext = "gpkg"
)
year |
A character string or numeric value with the release year of the file. One of \Sexpr[stage=render,results=rd]{giscoR:::db_values("urban_audit", "year",TRUE)}. |
epsg |
A character string or numeric value with the coordinate reference system as a 4-digit EPSG code. One of:
|
cache |
A logical value indicating whether to cache results. Defaults
to |
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
verbose |
A logical value. If |
spatialtype |
A character string with the type of geometry to return. Options available are:
|
country |
A character vector of country codes. It can be either a
vector of country names, a vector of ISO 3166-1 alpha-3 country codes or a
vector of Eurostat country codes. See also |
level |
A character string with the Urban Audit level. Possible values
are |
ext |
A character value with the extension of the file (default
|
For more information, see: Eurostat - Statistics Explained.
Cities are defined at several conceptual levels:
The core city ("CITIES"), using an administrative definition.
The Functional Urban Area/Large Urban Zone ("FUA"), approximating the
functional urban region.
Coverage includes the EU, Iceland, Norway and Switzerland. The dataset
includes polygon features, point features and a related attribute table
which can be joined on the URAU code field.
The "URAU_CATG" field defines the Urban Audit category:
"C" = City.
"F" = Functional urban area service type.
A sf object.
Check the download and usage provisions in gisco_attributions().
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
See gisco_bulk_download() to perform a bulk download of datasets.
See gisco_get_unit_urban_audit() to download single-unit files.
Statistical unit datasets:
gisco_get_census(),
gisco_get_coastal_lines(),
gisco_get_lau(),
gisco_get_nuts()
cities <- gisco_get_urban_audit(year = 2024, level = "CITIES")
if (!is.null(cities)) {
bcn <- cities[cities$URAU_NAME == "Barcelona", ]
library(ggplot2)
ggplot(bcn) +
geom_sf()
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.