This dataset represents the regions for levels 0, 1, 2 and 3 of the Nomenclature of Territorial Units for Statistics (NUTS) for 2024.
Format
A sf object with MULTIPOLYGON geometries, resolution:
1:20 million and EPSG:4326. It has
1798 rows and 10 variables:
NUTS_IDNUTS identifier.
LEVL_CODENUTS level code
(0,1,2,3).CNTR_CODEEurostat country code.
NAME_LATNNUTS name in Latin characters.
NUTS_NAMENUTS name in the local alphabet.
MOUNT_TYPEMountain type, see Details.
URBN_TYPEUrban type, see Details.
COAST_TYPECoastal type, see Details.
geoSame value as
NUTS_ID, provided for compatibility with eurostat.geometryGeometry field.
Details
MOUNT_TYPE: Mountain typology:
1: More than 50 % of the surface is covered by topographic mountain areas.2: More than 50 % of the regional population lives in topographic mountain areas.3: More than 50 % of the surface is covered by topographic mountain areas and where more than 50 % of the regional population lives in these mountain areas.4: Non-mountain region / other regions.0: No classification provided.
URBN_TYPE: Urban-rural typology:
1: Predominantly urban region.2: Intermediate region.3: Predominantly rural region.0: No classification provided.
COAST_TYPE: Coastal typology:
1: Coastal (on coast).2: Coastal (less than 50 % of population living within 50 km of the coastline).3: Non-coastal region.0: No classification provided.
Copyright
See the GISCO statistical unit copyright provisions: https://ec.europa.eu/eurostat/web/gisco/geodata/statistical-units.
Note
Check the download and usage provisions in gisco_attributions().
See also
Included datasets:
gisco_coastal_lines,
gisco_countries_2024,
gisco_countrycode,
gisco_db
Examples
data("gisco_nuts_2024")
head(gisco_nuts_2024)
#> Simple feature collection with 6 features and 9 fields
#> Geometry type: MULTIPOLYGON
#> Dimension: XY
#> Bounding box: xmin: 19.30265 ymin: 40.72684 xmax: 20.59774 ymax: 42.63906
#> Geodetic CRS: WGS 84
#> # A tibble: 6 × 10
#> NUTS_ID LEVL_CODE CNTR_CODE NAME_LATN NUTS_NAME MOUNT_TYPE URBN_TYPE
#> <chr> <int> <chr> <chr> <chr> <int> <int>
#> 1 AL011 3 AL Dibër Dibër NA NA
#> 2 AL012 3 AL Durrës Durrës NA NA
#> 3 AL013 3 AL Kukës Kukës NA NA
#> 4 AL014 3 AL Lezhë Lezhë NA NA
#> 5 AL015 3 AL Shkodër Shkodër NA NA
#> 6 AL021 3 AL Elbasan Elbasan NA NA
#> # ℹ 3 more variables: COAST_TYPE <int>, geo <chr>, geometry <MULTIPOLYGON [°]>