View source: R/gisco-attributions.R
| gisco_attributions | R Documentation |
Get the legal text to use for administrative and statistical data downloaded from GISCO. See section Copyright information.
For other datasets you may follow the Eurostat general copyright notice and license policy.
gisco_attributions(lang = "en", copyright = FALSE)
lang |
A character value with the language (two-letter ISO code). See countrycode::codelist and Details. |
copyright |
A logical value indicating whether to display the copyright notice on the console. |
Supported languages are:
"en": English.
"da": Danish.
"de": German.
"es": Spanish.
"fi": Finnish.
"fr": French.
"no": Norwegian.
"sv": Swedish.
Please consider contributing if you spot a mistake or want to add a new language.
A string with the attribution to be used.
The provisions described in this section apply to administrative and statistical data provided by the following functions:
Administrative units
gisco_get_communes().
gisco_get_countries().
gisco_get_postal_codes().
Statistical units
gisco_get_census().
gisco_get_coastal_lines().
gisco_get_lau().
gisco_get_nuts().
gisco_get_urban_audit().
When data downloaded from GISCO is used in any printed or electronic publication, in addition to any other provisions applicable to the whole Eurostat website, the data source must be acknowledged in the legend of the map and on the introductory page of the publication with the following copyright notice:
EN: © EuroGeographics for the administrative boundaries.
FR: © EuroGeographics pour les limites administratives.
DE: © EuroGeographics bezüglich der Verwaltungsgrenzen.
For publications in languages other than English, French or German, the translation of the copyright notice in the language of the publication shall be used.
If you intend to use the data commercially, please contact EuroGeographics for information about their license agreements.
gisco_attributions()
gisco_attributions(lang = "es", copyright = TRUE)
gisco_attributions(lang = "XXX")
# Get the list of codes from countrycode.
library(dplyr)
countrycode::codelist |>
select(country.name.en, iso2c)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.