Attribution for administrative and statistical GISCO data
Source:R/gisco-attributions.R
gisco_attributions.RdGet the legal text to use for administrative and statistical data downloaded from GISCO. See section Copyright information.
For other datasets you may follow the Eurostat general copyright notice and license policy.
Arguments
- lang
A character value with the language (two-letter ISO code). See countrycode::codelist and Details.
- copyright
A logical value indicating whether to display the copyright notice on the console.
Details
Supported languages are:
"en": English."da": Danish."de": German."es": Spanish."fi": Finnish."fr": French."no": Norwegian."sv": Swedish.
Please consider contributing if you spot a mistake or want to add a new language.
Copyright information
The provisions described in this section apply to administrative and statistical data provided by the following functions:
Administrative units
Statistical units
Copyright notice
When data downloaded from GISCO is used in any printed or electronic publication, in addition to any other provisions applicable to the whole Eurostat website, the data source must be acknowledged in the legend of the map and on the introductory page of the publication with the following copyright notice:
EN: © EuroGeographics for the administrative boundaries.
FR: © EuroGeographics pour les limites administratives.
DE: © EuroGeographics bezüglich der Verwaltungsgrenzen.
For publications in languages other than English, French or German, the translation of the copyright notice in the language of the publication shall be used.
If you intend to use the data commercially, please contact EuroGeographics for information about their license agreements.
Examples
gisco_attributions()
#> [1] "© EuroGeographics for the administrative boundaries"
gisco_attributions(lang = "es", copyright = TRUE)
#> ℹ Copyright notice
#>
#> When data downloaded from GISCO
#> is used in any printed or electronic publication,
#> in addition to any other provisions applicable to
#> the whole Eurostat website, the data source must
#> be acknowledged in the legend of the map and on
#> the introductory page of the publication with the
#> following copyright notice:
#>
#> - EN: © EuroGeographics for the administrative boundaries
#> - FR: © EuroGeographics pour les limites administratives
#> - DE: © EuroGeographics bezüglich der Verwaltungsgrenzen
#>
#> For publications in languages other than English,
#> French or German, the translation of the copyright
#> notice in the language of the publication shall be
#> used.
#>
#> If you intend to use the data commercially, please
#> contact EuroGeographics for information about
#> their license agreements.
#> [1] "© Eurogeographics para los límites administrativos"
gisco_attributions(lang = "XXX")
#> ! `lang` = "xxx" is not supported. Switching to English.
#> ℹ Consider contributing a translation: <https://github.com/rOpenGov/giscoR/issues>.
#> [1] "© EuroGeographics for the administrative boundaries"
# Get the list of codes from countrycode.
library(dplyr)
#>
#> Attaching package: ‘dplyr’
#> The following objects are masked from ‘package:stats’:
#>
#> filter, lag
#> The following objects are masked from ‘package:base’:
#>
#> intersect, setdiff, setequal, union
countrycode::codelist |>
select(country.name.en, iso2c)
#> # A tibble: 292 × 2
#> country.name.en iso2c
#> <chr> <chr>
#> 1 Afghanistan AF
#> 2 Albania AL
#> 3 Algeria DZ
#> 4 American Samoa AS
#> 5 Andorra AD
#> 6 Angola AO
#> 7 Anguilla AI
#> 8 Antarctica AQ
#> 9 Antigua & Barbuda AG
#> 10 Argentina AR
#> # ℹ 282 more rows