Database with different country code schemes and world regions
Source:R/data.R
gisco_countrycode.RdA tibble containing conversions between country code schemes (Eurostat, ISO 3166-1 alpha-2 and ISO 3166-1 alpha-3) and geographic regions from the World Bank and the UN (M49 Standard). This database was extracted from the countrycode package.
Format
A data frame with 249 rows and 13 variables:
ISO3_CODEISO 3166-1 alpha-3 code of each country.
CNTR_CODEEurostat country code.
iso2cISO 3166-1 alpha-2 code of each country.
iso.name.enISO English short name.
cldr.short.enEnglish short name as provided by the Unicode Common Locale Data Repository.
continentContinent from the World Bank.
un.region.codeUN M49 numeric region code.
un.region.nameUN M49 region name.
un.regionintermediate.codeUN M49 numeric intermediate region code.
un.regionintermediate.nameUN M49 intermediate region name.
un.regionsub.codeUN M49 numeric subregion code.
un.regionsub.nameUN M49 subregion name.
euLogical value indicating whether the country belongs to the European Union.
countrycode::codelist v1.6.1.
World regions
Regions follow the UN geographic regions (see https://unstats.un.org/unsd/methodology/m49/). Under this scheme Cyprus is assigned to Asia.
See also
gisco_get_countries(), countrycode::codelist.
See also Unicode Common Locale Data Repository.
Included datasets:
gisco_coastal_lines,
gisco_countries_2024,
gisco_db,
gisco_nuts_2024
Examples
data("gisco_countrycode")
dplyr::glimpse(gisco_countrycode)
#> Rows: 249
#> Columns: 13
#> $ ISO3_CODE <chr> "ABW", "AFG", "AGO", "AIA", "ALA", "ALB", "…
#> $ CNTR_CODE <chr> "AW", "AF", "AO", "AI", NA, "AL", "AD", "AE…
#> $ iso2c <chr> "AW", "AF", "AO", "AI", "AX", "AL", "AD", "…
#> $ iso.name.en <chr> "Aruba", "Afghanistan", "Angola", "Anguilla…
#> $ cldr.short.en <chr> "Aruba", "Afghanistan", "Angola", "Anguilla…
#> $ continent <chr> "Americas", "Asia", "Africa", "Americas", "…
#> $ un.region.code <dbl> 19, 142, 2, 19, 150, 150, 150, 142, 19, 142…
#> $ un.region.name <chr> "Americas", "Asia", "Africa", "Americas", "…
#> $ un.regionintermediate.code <dbl> 29, NA, 17, 29, NA, NA, NA, NA, 5, NA, NA, …
#> $ un.regionintermediate.name <chr> "Caribbean", NA, "Middle Africa", "Caribbea…
#> $ un.regionsub.code <dbl> 419, 34, 202, 419, 154, 39, 39, 145, 419, 1…
#> $ un.regionsub.name <chr> "Latin America and the Caribbean", "Souther…
#> $ eu <lgl> FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, F…