| gisco_db | R Documentation |
Database with the list of files in the GISCO API as of 2026-01-12.
A tibble with 9,714 rows.
This database is used to redirect the corresponding functions to the right API endpoints.
This version of the database is used if there is a problem during update.
Please use gisco_get_cached_db() with update_cache = TRUE to update the
corresponding API endpoints.
GISCO API datasets.json.
Other datasets:
gisco_coastal_lines,
gisco_countries_2024,
gisco_countrycode,
gisco_nuts_2024
Other database utils:
gisco_get_cached_db(),
gisco_get_metadata()
data("gisco_db")
gisco_db |>
dplyr::glimpse()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.