Database with the list of files in the GISCO API as of 2026-01-12.
Format
A tibble with 9,714 rows.
Details
This database is used to redirect the corresponding functions to the right API endpoints.
This version of the database is used if there is a problem during update.
Please use gisco_get_cached_db() with update_cache = TRUE to update the
corresponding API endpoints.
See also
Other datasets:
gisco_coastal_lines,
gisco_countries_2024,
gisco_countrycode,
gisco_nuts_2024
Other database utils:
gisco_get_cached_db(),
gisco_get_metadata()
Examples
data("gisco_db")
gisco_db |>
dplyr::glimpse()
#> Rows: 9,714
#> Columns: 11
#> $ id_giscor <chr> "coastal_lines", "coastal_lines", "coastal_lines", "coast…
#> $ year <dbl> 2006, 2006, 2006, 2006, 2006, 2006, 2006, 2006, 2006, 200…
#> $ epsg <dbl> 3035, 3035, 3035, 3035, 3035, 3035, 3035, 3035, 3035, 303…
#> $ resolution <dbl> 1, 1, 1, 1, 1, 1, 3, 3, 3, 3, 3, 3, 10, 10, 10, 10, 10, 1…
#> $ spatialtype <chr> "RG", "RG", "RG", "RG", "RG", "RG", "RG", "RG", "RG", "RG…
#> $ nuts_level <chr> NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, N…
#> $ level <chr> NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, N…
#> $ ext <chr> "csv", "geojson", "gpkg", "json", "pbf", "shp", "csv", "g…
#> $ api_file <chr> "csv/COAS_RG_01M_2006_3035.csv", "geojson/COAS_RG_01M_200…
#> $ api_entry <chr> "https://gisco-services.ec.europa.eu/distribution/v2/coas…
#> $ last_updated <date> 2026-01-12, 2026-01-12, 2026-01-12, 2026-01-12, 2026-01-…