View source: R/gisco-get-cached-db.R
| gisco_get_cached_db | R Documentation |
Returns or optionally updates the cached database with endpoints from the GISCO geodata distribution.
gisco_get_cached_db(update_cache = FALSE)
update_cache |
A logical value. If |
The cached database is stored in the giscoR cache path. See
gisco_set_cache_dir() for details. The cached database is used in
subsequent R sessions.
On new GISCO data releases, you can access the updated data by refreshing the cached database without waiting for a new version of giscoR.
A static database gisco_db is shipped with the package. This database is used if there is any problem during the update.
A tibble.
https://gisco-services.ec.europa.eu/distribution/v2/.
Database utilities:
gisco_db,
gisco_get_metadata()
gisco_get_cached_db() |>
dplyr::glimpse()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.