View source: R/gisco-get-census.R
| gisco_get_census | R Documentation |
This dataset shows pan-European communal boundaries for the corresponding census.
gisco_get_census(
year = 2011,
cache_dir = NULL,
update_cache = FALSE,
verbose = FALSE,
spatialtype = c("RG", "PT")
)
year |
A character string or numeric value with the release year of the
file.
Currently only |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
verbose |
A logical value. If |
spatialtype |
The type of geometry to return:
|
A sf object.
https://ec.europa.eu/eurostat/web/gisco/geodata/statistical-units/census.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/statistical-units.
See gisco_id_api_census_grid() to download via GISCO ID service API.
Statistical unit datasets:
gisco_get_coastal_lines(),
gisco_get_lau(),
gisco_get_nuts(),
gisco_get_urban_audit()
library(sf)
pts <- gisco_get_census(spatialtype = "PT")
pts
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.