This dataset shows pan-European administrative boundaries down to commune
level. Communes are equivalent to Local Administrative Units. See
gisco_get_lau().
Usage
gisco_get_communes(
year = 2016,
epsg = 4326,
cache = deprecated(),
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
spatialtype = "RG",
country = NULL,
ext = "shp"
)Source
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
Arguments
- year
A character string or numeric value with the release year of the file. One of
"2016","2013","2010","2008","2006","2004","2001".- epsg
A character string or numeric value with the map projection as a 4-digit EPSG code. One of:
"4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
- cache
. These functions always cache the result due to the size. See Caching strategies section in
gisco_set_cache_dir().- update_cache
A logical value indicating whether to refresh the cached file. Default is
FALSE. When set toTRUE, it forces a new download.- cache_dir
A character string with a path to a cache directory. See Caching strategies section in
gisco_set_cache_dir().- verbose
A logical value. If
TRUEdisplays informational messages.- spatialtype
A character string with the type of geometry to return. Options available are:
"RG": Regions -MULTIPOLYGON/POLYGONobject."LB": Labels -POINTobject."BN": Boundaries -LINESTRINGobject.Argument
countryis only applied whenspatialtypeis"RG"or"LB".
- country
A character vector of country codes. It can be either a vector of country names, a vector of ISO3 country codes or a vector of Eurostat country codes. See also
countrycode::countrycode().- ext
A character value with the extension of the file (default
"shp"). One of"shp","gpkg","geojson".
Value
A sf object.
Details
The Nomenclature of Territorial Units for Statistics (NUTS) and the LAU nomenclature are hierarchical classifications of statistical regions that together subdivide the EU economic territory into regions of five different levels (NUTS 1, 2 and 3 and LAU, respectively, moving from larger to smaller territorial units).
The dataset is based on EuroBoundaryMap from EuroGeographics. Geographical extent covers the European Union 28, EFTA countries and candidate countries. The scale of the dataset is 1:100 000.
The LAU classification is not covered by any legislative act.
Note
Check the download and usage provisions in gisco_attributions().
See also
See gisco_bulk_download() to perform a bulk download of datasets.
Other administrative units datasets:
gisco_get_countries(),
gisco_get_postal_codes()
Examples
ire_comm <- gisco_get_communes(spatialtype = "LB", country = "Ireland")
if (!is.null(ire_comm)) {
library(ggplot2)
ggplot(ire_comm) +
geom_sf(shape = 21, col = "#009A44", size = 0.5) +
labs(
title = "Communes in Ireland",
subtitle = "Year 2016",
caption = gisco_attributions()
) +
theme_void() +
theme(text = element_text(
colour = "#009A44",
family = "serif", face = "bold"
))
}