The dataset contains information on main healthcare services considered to be 'hospitals' by Member States.
gisco_get_healthcare(
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
country = NULL
)A logical whether to do caching. Default is TRUE.
A logical whether to update cache. Default is FALSE.
When set to TRUE it would force a fresh download of the source
.geojson file.
A path to a cache directory. See Details on gisco_get.
Display information. Useful for debugging,
default is FALSE.
Optional. A character vector of country codes.
See Details on gisco_get.
A POINT object.
Files are distributed on EPSG:4326. Metadata available on https://gisco-services.ec.europa.eu/pub/healthcare/metadata.pdf.