View source: R/gisco-get-metadata.R
| gisco_get_metadata | R Documentation |
Get a table with names and IDs of administrative and statistical units.
gisco_get_metadata(
id = c("nuts", "countries", "urban_audit"),
year = 2024,
verbose = FALSE
)
id |
A character string with the unit type to download. Accepted values
are |
year |
A character string or numeric value with the release year of the metadata. |
verbose |
A logical value. If |
A tibble.
https://gisco-services.ec.europa.eu/distribution/v2/.
gisco_get_nuts(), gisco_get_countries(), gisco_get_urban_audit().
Database utilities:
gisco_db,
gisco_get_cached_db()
cities <- gisco_get_metadata(id = "urban_audit", year = 2020)
cities
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.