View source: R/gisco-get-nuts.R
| gisco_get_nuts | R Documentation |
The GISCO statistical unit dataset represents the NUTS (nomenclature of territorial units for statistics) and statistical regions by means of multipart polygon, polyline and point topology. The NUTS geographical information is completed by attribute tables and a set of cartographic help lines to better visualize multipart polygonal regions.
NUTS is a hierarchical system divided into three levels:
NUTS 1: major socio-economic regions.
NUTS 2: basic regions for the application of regional policies.
NUTS 3: small regions for specific diagnoses.
There is also a NUTS 0 level, which usually corresponds to national boundaries.
Downloads data from the aggregated GISCO NUTS file, which contains data for
all countries at the requested NUTS level or levels. To download single-unit
NUTS files, use gisco_get_unit_nuts().
gisco_get_nuts(
year = 2024,
epsg = 4326,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
resolution = 20,
spatialtype = "RG",
country = NULL,
nuts_id = NULL,
nuts_level = c("all", "0", "1", "2", "3"),
ext = "gpkg"
)
year |
A character string or numeric value with the release year of the file. One of \Sexpr[stage=render,results=rd]{giscoR:::db_values("nuts", "year",TRUE)}. |
epsg |
A character string or numeric value with the coordinate reference system as a 4-digit EPSG code. One of:
|
cache |
A logical value indicating whether to cache results. Defaults
to |
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
verbose |
A logical value. If |
resolution |
A character string or numeric value with the geospatial data resolution. One of:
|
spatialtype |
A character string with the type of geometry to return. Options available are:
|
country |
A character vector of country codes. It can be either a
vector of country names, a vector of ISO 3166-1 alpha-3 country codes or a
vector of Eurostat country codes. See also |
nuts_id |
An optional character vector of NUTS IDs. |
nuts_level |
A character string with the NUTS level. One of |
ext |
A character value with the extension of the file (default
|
The NUTS nomenclature is a hierarchical classification of statistical regions and subdivides the EU economic territory into regions of three different levels (NUTS 1, 2 and 3, moving respectively from larger to smaller territorial units). NUTS 1 is the most aggregated level. Additional country-level NUTS 0 data are also available for countries where the statistical national level does not coincide with the administrative boundaries.
The NUTS classification has been officially established through Commission Delegated Regulation 2019/1755. A non-official NUTS-like classification has been defined for the EFTA countries, candidate countries and potential candidates based on a bilateral agreement between Eurostat and the respective statistical agencies.
An introduction to the NUTS classification is available here: https://ec.europa.eu/eurostat/web/nuts/overview.
A sf object.
Check the download and usage provisions in gisco_attributions().
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
gisco_nuts_2024, eurostat::get_eurostat_geospatial().
See gisco_bulk_download() to perform a bulk download of datasets.
See gisco_get_unit_nuts() to download single-unit files.
See gisco_id_api_nuts() to download via GISCO ID service API.
Statistical unit datasets:
gisco_get_census(),
gisco_get_coastal_lines(),
gisco_get_lau(),
gisco_get_urban_audit()
nuts2 <- gisco_get_nuts(nuts_level = 2)
library(ggplot2)
ggplot(nuts2) +
geom_sf() +
# ETRS89 / ETRS-LAEA
coord_sf(
crs = 3035, xlim = c(2377294, 7453440),
ylim = c(1313597, 5628510)
) +
labs(title = "NUTS 2 levels")
# NUTS 3 for Germany.
germany_nuts3 <- gisco_get_nuts(nuts_level = 3, country = "Germany")
ggplot(germany_nuts3) +
geom_sf() +
labs(
title = "NUTS 3 levels",
subtitle = "Germany",
caption = gisco_attributions()
)
# Select specific regions
select_nuts <- gisco_get_nuts(nuts_id = c("ES2", "FRJ", "FRL", "ITC"))
ggplot(select_nuts) +
geom_sf(aes(fill = CNTR_CODE)) +
scale_fill_viridis_d()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.