View source: R/gisco-get-units.R
| gisco_get_units | R Documentation |
Deprecated. Use one of these replacements:
gisco_get_metadata() for mode = "df".
?gisco_get_unit functions for mode = "sf".
gisco_get_units(
id_giscoR = c("nuts", "countries", "urban_audit"),
unit = "ES4",
mode = c("sf", "df"),
year = 2016,
epsg = 4326,
cache = TRUE,
update_cache = FALSE,
cache_dir = NULL,
verbose = FALSE,
resolution = 20,
spatialtype = "RG"
)
id_giscoR |
A character string with the |
unit |
A unit ID to download. |
mode |
A character string controlling the output of the function.
Possible values are |
year |
A character string or numeric value with the release year of the file. |
epsg |
A character string or numeric value with the coordinate reference system as a 4-digit EPSG code. One of:
|
cache |
A logical value indicating whether to cache results. Defaults
to |
update_cache |
A logical value indicating whether to refresh the
cached file. Defaults to |
cache_dir |
A character string with a path to a cache directory. See
Caching strategies section in |
verbose |
A logical value. If |
resolution |
A character string or numeric value with the geospatial data resolution. One of:
|
spatialtype |
A character string with the type of geometry to return. Options available are:
|
A sf object when mode = "sf" or a
tibble when mode = "df".
Check the download and usage provisions in gisco_attributions().
https://gisco-services.ec.europa.eu/distribution/v2/
All source files are .geojson files.
gisco_get_metadata(), ?gisco_get_unit functions.
# Equivalent metadata call.
gisco_get_units("nuts", mode = "df", year = 2016)
# ->
gisco_get_metadata("nuts", year = 2016)
# Equivalent `sf` call for NUTS.
gisco_get_units("nuts", unit = "ES111", mode = "sf", year = 2016)
# ->
gisco_get_unit_nuts(unit = "ES111", year = 2016)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.