This dataset contains the boundaries of cities ("CITIES"), greater cities
("GREATER_CITIES") and functional urban areas ("FUA") as defined
according to the EC-OECD city definition. This is used for the Eurostat
Urban Audit data collection.
This function gets data from the aggregated GISCO Urban Audit file. To
download individual Urban Audit files, use gisco_get_unit_urban_audit().
https://gisco-services.ec.europa.eu/distribution/v2/.
Copyright: https://ec.europa.eu/eurostat/web/gisco/geodata/administrative-units.
Arguments
- year
A character string or numeric value with the release year of the file. One of
"2024","2021","2020","2018","2014","2004","2001".- epsg
A character string or numeric value with the map projection as a 4-digit EPSG code. One of:
"4326": WGS84."3035": ETRS89 / ETRS-LAEA."3857": Pseudo-Mercator.
- cache
A logical value indicating whether to cache results. Default is
TRUE. See Caching strategies section ingisco_set_cache_dir().- update_cache
A logical value indicating whether to refresh the cached file. Default is
FALSE. When set toTRUE, it forces a new download.- cache_dir
A character string with a path to a cache directory. See Caching strategies section in
gisco_set_cache_dir().- verbose
A logical value. If
TRUEdisplays informational messages.- spatialtype
A character string with the type of geometry to return. Options available are:
"RG": Regions -MULTIPOLYGON/POLYGONobject."LB": Labels -POINTobject.
- country
A character vector of country codes. It can be either a vector of country names, a vector of ISO3 country codes or a vector of Eurostat country codes. See also
countrycode::countrycode().- level
A character string with the Urban Audit level. Possible values are
"all"(the default), which downloads the full dataset,"CITIES","FUA"and, for versions prior toyear = 2020,"GREATER_CITIES","CITY","KERN"or"LUZ".- ext
A character value with the extension of the file (default
"gpkg"). One of"shp","gpkg","geojson".
Value
A sf object.
Details
See more at: Eurostat - Statistics Explained.
The cities are defined at several conceptual levels:
The core city (
"CITIES"), using an administrative definition.The Functional Urban Area/Large Urban Zone (
"FUA"), approximating the functional urban region. The coverage is the EU plus Iceland, Norway and Switzerland. The dataset includes polygon features, point features and a related attribute table which can be joined on the URAU code field.
The "URAU_CATG" field defines the Urban Audit category:
"C"= City."F"= Functional urban area service type.
Note
Check the download and usage provisions in gisco_attributions().
See also
See gisco_bulk_download() to perform a bulk download of datasets.
See gisco_get_unit_urban_audit() to download single files.
Other statistical units datasets:
gisco_get_census(),
gisco_get_coastal_lines(),
gisco_get_lau(),
gisco_get_nuts()