| gisco_set_cache_dir | R Documentation |
Stores your cache_dir path on your local machine and loads it in future
sessions. Use Sys.getenv("GISCO_CACHE_DIR") or
gisco_detect_cache_dir() to find your cached path.
gisco_set_cache_dir(
cache_dir = NULL,
overwrite = FALSE,
install = FALSE,
verbose = TRUE
)
gisco_detect_cache_dir()
cache_dir |
A path to a cache directory. If |
overwrite |
If |
install |
If |
verbose |
A logical value. If |
By default, when no cache cache_dir is set, the package uses a folder
inside base::tempdir() (so files are temporary and are removed when the
R session ends). To persist a cache across R sessions, use
gisco_set_cache_dir(cache_dir, install = TRUE), which writes the chosen
path to a small configuration file under
tools::R_user_dir("giscoR", "config").
gisco_set_cache_dir() invisibly returns a character string with the path
to your cache_dir, but it is mainly called for its side effect.
gisco_detect_cache_dir() returns the path to the cache_dir used in this
session.
Some files can be read from their online source without caching using the
option cache = FALSE. Otherwise the source file is downloaded to
your computer. giscoR implements the following caching options:
For occasional use, rely on the default tempdir()-based cache (no
install).
Modify the cache for a single session by setting
gisco_set_cache_dir(cache_dir = "a/path/here").
For reproducible workflows, install a persistent cache with
gisco_set_cache_dir(cache_dir = "a/path/here", install = TRUE), which
keeps the path across R sessions.
For caching specific files, use the cache_dir argument in the
corresponding function. See example in gisco_get_nuts().
Sometimes cached files may be corrupt. In that case, try downloading the
data by setting update_cache = TRUE in the corresponding function.
If you experience a download problem, try to download the corresponding
file by another method and save it in your cache_dir. Use
verbose = TRUE to debug the API query and gisco_detect_cache_dir() to
identify your cached path.
In giscoR >= 1.0.0 the location of the configuration file has
moved from rappdirs::user_config_dir("giscoR", "R") to
tools::R_user_dir("giscoR", "config"). We have implemented a function
that migrates previous configuration files from one location to another
with a message. The message appears only once to inform you of the
migration.
tools::R_user_dir()
Other cache utilities:
gisco_clear_cache()
# Do not run this. It modifies your current state.
## Not run:
my_cache <- gisco_detect_cache_dir()
# Set an example cache.
ex <- file.path(tempdir(), "example", "cachenew")
gisco_set_cache_dir(ex)
gisco_detect_cache_dir()
# Restore the initial cache.
gisco_set_cache_dir(my_cache)
identical(my_cache, gisco_detect_cache_dir())
## End(Not run)
gisco_detect_cache_dir()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.